@@ -18,9 +18,8 @@ has serialize_class => isa(object);
 
 sub validation {
 	my ($self, $value) = @_;
-        if (ref($value || "SCALAR") =~ m/ARRAY|HASH|SCALAR/) {
-        	$value = $self->object_class->instantiate($self, 0, $value);
-		$self->blessed(1);
+	if (ref($value || "SCALAR") =~ m/ARRAY|HASH|SCALAR/) {
+		$value = $self->inflation($value);
 	}
 	return $value;
 }
@@ -28,14 +27,18 @@ sub validation {
 sub inflation {
 	my ($self, $value) = @_;
 
-        if (! ref $value) {
-        	$value = $self->serialize_class->parse($value);
+	if (! ref $value) {
+		$value = $self->serialize_class->parse($value);
 		$self->reference(1);
 	}
 
 	return ref($value) =~ m/HASH|ARRAY|SCALAR/  ?  do {
 		$self->blessed(1);
-		$value = $self->object_class->instantiate($self, 0, $value);
+		if (ref $value eq 'ARRAY') {
+			$value = [ map { $self->object_class->instantiate($self, 0, $_) } @{ $value } ];
+		} else {
+			$value = $self->object_class->instantiate($self, 0, $value);
+		}
 		$value;
 	} : $value;
 }
@@ -44,6 +47,10 @@ sub deflation {
 	my ($self, $value) = @_;
 	if ($self->blessed) {
 		$value = deep_unblessed $value;
+		$value = { map {
+			my $val = ref $value->{$_} ? $value->{$_}->store_row() : $value->{$_};
+			$_ => $val
+		}  keys %{ $value } };
 	}
 	if ($self->reference && ref $value) {
 		$value = $self->serialize_class->stringify($value);
